@@ -60,6 +60,7 @@ def _get_columns_network(item):
         'ipv6_address_scope_id': 'ipv6_address_scope',
         'tags': 'tags',
     }
+    hidden_columns = ['location', 'tenant_id']
     hidden_columns = ['location']
     return utils.get_osc_show_columns_for_sdk_resource(
         item,
@@ -270,14 +271,16 @@ class CreateNetwork(common.NetworkAndComputeShowOne,
             '--external',
             action='store_true',
             help=self.enhance_help_neutron(
-                _("Set this network as an external network "
+                _("The network has an external routing facility that's not "
+                  "managed by Neutron and can be used as in: "
+                  "openstack router set --external-gateway NETWORK "
                   "(external-net extension required)"))
         )
         external_router_grp.add_argument(
             '--internal',
             action='store_true',
             help=self.enhance_help_neutron(
-                _("Set this network as an internal network (default)"))
+                _("Opposite of '--external' (default)"))
         )
         default_router_grp = parser.add_mutually_exclusive_group()
         default_router_grp.add_argument(
@@ -664,12 +667,12 @@ class SetNetwork(common.NeutronCommandWithExtraArgs):
         )
         parser.add_argument(
             '--description',
-            metavar="<description",
+            metavar="<description>",
             help=_("Set network description")
         )
         parser.add_argument(
             '--mtu',
-            metavar="<mtu",
+            metavar="<mtu>",
             help=_("Set network mtu")
         )
         port_security_group = parser.add_mutually_exclusive_group()
@@ -689,13 +692,15 @@ class SetNetwork(common.NeutronCommandWithExtraArgs):
         external_router_grp.add_argument(
             '--external',
             action='store_true',
-            help=_("Set this network as an external network "
+            help=_("The network has an external routing facility that's not "
+                   "managed by Neutron and can be used as in: "
+                   "openstack router set --external-gateway NETWORK "
                    "(external-net extension required)")
         )
         external_router_grp.add_argument(
             '--internal',
             action='store_true',
-            help=_("Set this network as an internal network")
+            help=_("Opposite of '--external'")
         )
         default_router_grp = parser.add_mutually_exclusive_group()
         default_router_grp.add_argument(
