@@ -10,7 +10,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import json
 import uuid
 
 from openstackclient.tests.functional.volume.v2 import common
@@ -22,29 +21,32 @@ class QosTests(common.BaseVolumeTests):
     def test_volume_qos_create_delete_list(self):
         """Test create, list, delete multiple"""
         name1 = uuid.uuid4().hex
-        cmd_output = json.loads(self.openstack(
-            'volume qos create -f json ' +
-            name1
-        ))
+        cmd_output = self.openstack(
+            'volume qos create ' +
+            name1,
+            parse_output=True,
+        )
         self.assertEqual(
             name1,
             cmd_output['name']
         )
 
         name2 = uuid.uuid4().hex
-        cmd_output = json.loads(self.openstack(
-            'volume qos create -f json ' +
-            name2
-        ))
+        cmd_output = self.openstack(
+            'volume qos create ' +
+            name2,
+            parse_output=True,
+        )
         self.assertEqual(
             name2,
             cmd_output['name']
         )
 
         # Test list
-        cmd_output = json.loads(self.openstack(
-            'volume qos list -f json'
-        ))
+        cmd_output = self.openstack(
+            'volume qos list',
+            parse_output=True,
+        )
         names = [x["Name"] for x in cmd_output]
         self.assertIn(name1, names)
         self.assertIn(name2, names)
@@ -57,12 +59,13 @@ class QosTests(common.BaseVolumeTests):
         """Tests create volume qos, set, unset, show, delete"""
 
         name = uuid.uuid4().hex
-        cmd_output = json.loads(self.openstack(
-            'volume qos create -f json ' +
+        cmd_output = self.openstack(
+            'volume qos create ' +
             '--consumer front-end '
             '--property Alpha=a ' +
-            name
-        ))
+            name,
+            parse_output=True,
+        )
         self.addCleanup(self.openstack, 'volume qos delete ' + name)
         self.assertEqual(
             name,
@@ -88,10 +91,11 @@ class QosTests(common.BaseVolumeTests):
         self.assertOutput('', raw_output)
 
         # Test volume qos show
-        cmd_output = json.loads(self.openstack(
-            'volume qos show -f json ' +
-            name
-        ))
+        cmd_output = self.openstack(
+            'volume qos show ' +
+            name,
+            parse_output=True,
+        )
         self.assertEqual(
             name,
             cmd_output['name']
@@ -109,10 +113,11 @@ class QosTests(common.BaseVolumeTests):
         )
         self.assertOutput('', raw_output)
 
-        cmd_output = json.loads(self.openstack(
-            'volume qos show -f json ' +
-            name
-        ))
+        cmd_output = self.openstack(
+            'volume qos show ' +
+            name,
+            parse_output=True,
+        )
         self.assertEqual(
             name,
             cmd_output['name']
@@ -125,10 +130,11 @@ class QosTests(common.BaseVolumeTests):
     def test_volume_qos_asso_disasso(self):
         """Tests associate and disassociate qos with volume type"""
         vol_type1 = uuid.uuid4().hex
-        cmd_output = json.loads(self.openstack(
-            'volume type create -f json ' +
-            vol_type1
-        ))
+        cmd_output = self.openstack(
+            'volume type create ' +
+            vol_type1,
+            parse_output=True,
+        )
         self.assertEqual(
             vol_type1,
             cmd_output['name']
@@ -136,10 +142,11 @@ class QosTests(common.BaseVolumeTests):
         self.addCleanup(self.openstack, 'volume type delete ' + vol_type1)
 
         vol_type2 = uuid.uuid4().hex
-        cmd_output = json.loads(self.openstack(
-            'volume type create -f json ' +
-            vol_type2
-        ))
+        cmd_output = self.openstack(
+            'volume type create ' +
+            vol_type2,
+            parse_output=True,
+        )
         self.assertEqual(
             vol_type2,
             cmd_output['name']
@@ -147,10 +154,11 @@ class QosTests(common.BaseVolumeTests):
         self.addCleanup(self.openstack, 'volume type delete ' + vol_type2)
 
         name = uuid.uuid4().hex
-        cmd_output = json.loads(self.openstack(
-            'volume qos create -f json ' +
-            name
-        ))
+        cmd_output = self.openstack(
+            'volume qos create ' +
+            name,
+            parse_output=True,
+        )
         self.assertEqual(
             name,
             cmd_output['name']
@@ -169,10 +177,11 @@ class QosTests(common.BaseVolumeTests):
         )
         self.assertOutput('', raw_output)
 
-        cmd_output = json.loads(self.openstack(
-            'volume qos show -f json ' +
-            name
-        ))
+        cmd_output = self.openstack(
+            'volume qos show ' +
+            name,
+            parse_output=True,
+        )
         types = cmd_output["associations"]
         self.assertIn(vol_type1, types)
         self.assertIn(vol_type2, types)
@@ -184,10 +193,11 @@ class QosTests(common.BaseVolumeTests):
             ' ' + name
         )
         self.assertOutput('', raw_output)
-        cmd_output = json.loads(self.openstack(
-            'volume qos show -f json ' +
-            name
-        ))
+        cmd_output = self.openstack(
+            'volume qos show ' +
+            name,
+            parse_output=True,
+        )
         types = cmd_output["associations"]
         self.assertNotIn(vol_type1, types)
         self.assertIn(vol_type2, types)
@@ -198,10 +208,11 @@ class QosTests(common.BaseVolumeTests):
             name + ' ' + vol_type1
         )
         self.assertOutput('', raw_output)
-        cmd_output = json.loads(self.openstack(
-            'volume qos show -f json ' +
-            name
-        ))
+        cmd_output = self.openstack(
+            'volume qos show ' +
+            name,
+            parse_output=True,
+        )
         types = cmd_output["associations"]
         self.assertIn(vol_type1, types)
         self.assertIn(vol_type2, types)
@@ -211,8 +222,9 @@ class QosTests(common.BaseVolumeTests):
             '--all ' + name
         )
         self.assertOutput('', raw_output)
-        cmd_output = json.loads(self.openstack(
-            'volume qos show -f json ' +
-            name
-        ))
+        cmd_output = self.openstack(
+            'volume qos show ' +
+            name,
+            parse_output=True,
+        )
         self.assertNotIn("associations", cmd_output.keys())
