@@ -40,9 +40,9 @@ class TestFloatingIPNetwork(network_fakes.TestNetworkV2):
 class TestCreateFloatingIPNetwork(TestFloatingIPNetwork):
 
     # Fake data for option tests.
-    floating_network = network_fakes.FakeNetwork.create_one_network()
+    floating_network = network_fakes.create_one_network()
     subnet = network_fakes.FakeSubnet.create_one_subnet()
-    port = network_fakes.FakePort.create_one_port()
+    port = network_fakes.create_one_port()
 
     # The floating ip created.
     floating_ip = network_fakes.FakeFloatingIP.create_one_floating_ip(
@@ -378,10 +378,10 @@ class TestListFloatingIPNetwork(TestFloatingIPNetwork):
 
     # The floating ips to list up
     floating_ips = network_fakes.FakeFloatingIP.create_floating_ips(count=3)
-    fake_network = network_fakes.FakeNetwork.create_one_network({
+    fake_network = network_fakes.create_one_network({
         'id': 'fake_network_id',
     })
-    fake_port = network_fakes.FakePort.create_one_port({
+    fake_port = network_fakes.create_one_port({
         'id': 'fake_port_id',
     })
     fake_router = network_fakes.FakeRouter.create_one_router({
@@ -700,9 +700,9 @@ class TestShowFloatingIPNetwork(TestFloatingIPNetwork):
 class TestSetFloatingIP(TestFloatingIPNetwork):
 
     # Fake data for option tests.
-    floating_network = network_fakes.FakeNetwork.create_one_network()
+    floating_network = network_fakes.create_one_network()
     subnet = network_fakes.FakeSubnet.create_one_subnet()
-    port = network_fakes.FakePort.create_one_port()
+    port = network_fakes.create_one_port()
 
     # The floating ip to be set.
     floating_ip = network_fakes.FakeFloatingIP.create_one_floating_ip(
@@ -932,9 +932,9 @@ class TestSetFloatingIP(TestFloatingIPNetwork):
 
 class TestUnsetFloatingIP(TestFloatingIPNetwork):
 
-    floating_network = network_fakes.FakeNetwork.create_one_network()
+    floating_network = network_fakes.create_one_network()
     subnet = network_fakes.FakeSubnet.create_one_subnet()
-    port = network_fakes.FakePort.create_one_port()
+    port = network_fakes.create_one_port()
 
     # The floating ip to be unset.
     floating_ip = network_fakes.FakeFloatingIP.create_one_floating_ip(
